
#ifndef _C10_co469_
#define _C10_co469_

#ifdef __cplusplus
extern "C" {
#endif

extern void F439_3057(EIF_REFERENCE);
extern void EIF_Minit469(void);
extern long O2736[];

#ifdef __cplusplus
}
#endif

#endif
